summaryrefslogtreecommitdiff
path: root/src/mongo/db/repl/oplog_applier_impl.cpp
diff options
context:
space:
mode:
authorA. Jesse Jiryu Davis <jesse@mongodb.com>2019-11-22 01:47:10 +0000
committerevergreen <evergreen@mongodb.com>2019-11-22 01:47:10 +0000
commit355937f48d5c505d606ac1c211fb6427179d8a5b (patch)
tree728f34e6b2978dae7e3da2c667d49794ce5d8ff5 /src/mongo/db/repl/oplog_applier_impl.cpp
parent48c3f738be846ddb7ad5309ef834f851eed0fd1a (diff)
downloadmongo-355937f48d5c505d606ac1c211fb6427179d8a5b.tar.gz
SERVER-43000 Rename OpQueueBatcher to OplogBatcher
Diffstat (limited to 'src/mongo/db/repl/oplog_applier_impl.cpp')
-rw-r--r--src/mongo/db/repl/oplog_applier_impl.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/repl/oplog_applier_impl.cpp b/src/mongo/db/repl/oplog_applier_impl.cpp
index f1c12d1e68a..f5716c2a49b 100644
--- a/src/mongo/db/repl/oplog_applier_impl.cpp
+++ b/src/mongo/db/repl/oplog_applier_impl.cpp
@@ -371,9 +371,9 @@ OplogApplierImpl::OplogApplierImpl(executor::TaskExecutor* executor,
void OplogApplierImpl::_run(OplogBuffer* oplogBuffer) {
// Start up a thread from the batcher to pull from the oplog buffer into the batcher's oplog
// batch.
- _opQueueBatcher->startup(_storageInterface);
+ _oplogBatcher->startup(_storageInterface);
- ON_BLOCK_EXIT([this] { _opQueueBatcher->shutdown(); });
+ ON_BLOCK_EXIT([this] { _oplogBatcher->shutdown(); });
// We don't start data replication for arbiters at all and it's not allowed to reconfig
// arbiterOnly field for any member.
@@ -384,7 +384,7 @@ void OplogApplierImpl::_run(OplogBuffer* oplogBuffer) {
? new ApplyBatchFinalizerForJournal(_replCoord)
: new ApplyBatchFinalizer(_replCoord)};
- while (true) { // Exits on message from OpQueueBatcher.
+ while (true) { // Exits on message from OplogBatcher.
// Use a new operation context each iteration, as otherwise we may appear to use a single
// collection name to refer to collections with different UUIDs.
const ServiceContext::UniqueOperationContext opCtxPtr = cc().makeOperationContext();
@@ -407,7 +407,7 @@ void OplogApplierImpl::_run(OplogBuffer* oplogBuffer) {
// Blocks up to a second waiting for a batch to be ready to apply. If one doesn't become
// ready in time, we'll loop again so we can do the above checks periodically.
- OplogBatch ops = _opQueueBatcher->getNextBatch(Seconds(1));
+ OplogBatch ops = _oplogBatcher->getNextBatch(Seconds(1));
if (ops.empty()) {
if (ops.mustShutdown()) {
// Shut down and exit oplog application loop.